Primary Authors
===============

* __[Richard Jackson](https://github.com/RichJackson)__

* __[Elliot Ford](https://github.com/EFord36)__

* __[Wonjin Yoon](https://github.com/wonjininfo)__

* __[Rolando Fernandez](https://github.com/rsbf)__


Other Contributors
==================

Please see the GitHub commit log for a list of recent contributors.

We also thank the following organisations and individuals for their support:

* Explosion.ai
* Bruno Contrino
* Vladimir Poroshin
